[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.4302359.svg)](https://doi.org/10.5281/zenodo.4302359)

The documentation of TranSPHIRE moved to [here](https://transphire.readthedocs.io).


# Transphire

Cryo-EM on the fly processing pipeline.

If you have any questions contact:  
markus.stabrin@mpi-dortmund.mpg.de

## Installation

You can find a description how to install TranSPHIRE here: [Installation instructions](https://github.com/MPI-Dortmund/transphire/wiki/Installation)

## Getting started

You can find an extensive Tutorial in how to use TranSPHIRE:
[Getting started with TranSPHIRE](https://github.com/MPI-Dortmund/transphire/wiki/getting-started)

## FAQ

Please refere to this link: [https://github.com/MPI-Dortmund/transphire/wiki/FAQ](https://github.com/MPI-Dortmund/transphire/wiki/FAQ)
